#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_INBTRUE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_INBTRUE_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/inbtrue.hpp>

#endif
